@@ -8,8 +8,9 @@ from pathlib import Path
 
 import gi
 gi.require_version('GLib', '2.0')
-gi.require_version('Hinawa', '3.0')
-from gi.repository import GLib, Hinawa
+gi.require_version('Hinawa', '4.0')
+gi.require_version('Hitaki', '0.0')
+from gi.repository import GLib, Hinawa, Hitaki
 
 from hinawa_utils.fireface.ff_config_rom_parser import FFConfigRomParser
 from hinawa_utils.fireface.ff_option_reg import FFOptionReg
@@ -20,7 +21,7 @@ from hinawa_utils.fireface.ff_out_reg import FFOutRegs
 __all__ = ['FFUnit']
 
 
-class FFUnit(Hinawa.SndUnit):
+class FFUnit(Hitaki.SndUnit):
     __MODELS = {
         0x000001:   'Fireface800',
         0x000002:   'Fireface400',
@@ -54,23 +55,28 @@ class FFUnit(Hinawa.SndUnit):
 
     def __init__(self, path):
         super().__init__()
-        self.open(path)
+        self.open(path, 0)
 
         ctx = GLib.MainContext.new()
-        self.create_source().attach(ctx)
+        _, src = self.create_source()
+        src.attach(ctx)
         self.__unit_dispatcher = GLib.MainLoop.new(ctx, False)
         self.__unit_th = Thread(target=lambda d: d.run(), args=(self.__unit_dispatcher, ))
         self.__unit_th.start()
 
-        node = self.get_node()
+        fw_node_path = '/dev/{}'.format(self.get_property('node-device'))
+        self.__node = Hinawa.FwNode.new()
+        self.__node.open(fw_node_path, 0)
         ctx = GLib.MainContext.new()
-        node.create_source().attach(ctx)
+        _, src = self.__node.create_source()
+        src.attach(ctx)
         self.__node_dispatcher = GLib.MainLoop.new(ctx, False)
         self.__node_th = Thread(target=lambda d: d.run(), args=(self.__node_dispatcher, ))
         self.__node_th.start()
 
         parser = FFConfigRomParser()
-        info = parser.parse_rom(self.get_node().get_config_rom())
+        _, image = self.get_node().get_config_rom()
+        info = parser.parse_rom(image)
         if info['model_id'] not in self.__MODELS:
             raise OSError('Unsupported model.')
 
@@ -104,6 +110,9 @@ class FFUnit(Hinawa.SndUnit):
     def __exit__(self, ex_type, ex_value, trace):
         self.release()
 
+    def get_node(self):
+        return self.__node
+
     def __read_cache_from_file(self):
         self.__option_cache = []
         self.__mixer_cache = []
@@ -157,10 +166,10 @@ class FFUnit(Hinawa.SndUnit):
         if self.__name == 'Fireface400':
             FFOptionReg.build_single_option(self.__option_cache,
                                             'midi-low-addr', '0x00000000', True)
-        req = Hinawa.FwReq()
+        req = Hinawa.FwReq.new()
         frames = pack('<3I', *self.__option_cache)
-        req.transaction(self.get_node(), Hinawa.FwTcode.WRITE_BLOCK_REQUEST,
-                        self.__regs[0], len(frames), frames)
+        _, _ = req.transaction(self.get_node(), Hinawa.FwTcode.WRITE_BLOCK_REQUEST,
+                               self.__regs[0], len(frames), frames, 100)
 
     def __create_multiple_option_initial_cache(self, cache):
         default_params = {
@@ -243,11 +252,11 @@ class FFUnit(Hinawa.SndUnit):
                                                item)
 
     def get_sync_status(self):
-        req = Hinawa.FwReq()
+        req = Hinawa.FwReq.new()
         frames = bytearray(8)
-        frames = req.transaction(self.get_node(),
-                    Hinawa.FwTcode.READ_BLOCK_REQUEST,
-                    0x0000801c0000, 8, frames)
+        _, frames = req.transaction(self.get_node(),
+                                    Hinawa.FwTcode.READ_BLOCK_REQUEST,
+                                    0x0000801c0000, 8, frames, 100)
         quads = unpack('<2I', frames)
 
         return FFStatusReg.parse(quads)
@@ -290,9 +299,10 @@ class FFUnit(Hinawa.SndUnit):
         offset = FFMixerRegs.calculate_src_offset(self.__spec, target, src)
         val = self.__build_val_from_db(db)
         data = pack('<I', val)
-        req = Hinawa.FwReq()
-        req.transaction(self.get_node(), Hinawa.FwTcode.WRITE_BLOCK_REQUEST,
-                        self.__regs[1] + offset, len(data), data)
+        req = Hinawa.FwReq.new()
+        _, _ = req.transaction(self.get_node(),
+                               Hinawa.FwTcode.WRITE_BLOCK_REQUEST,
+                               self.__regs[1] + offset, len(data), data, 100)
         self.__mixer_cache[offset // 4] = val
         self.__write_cache_to_file()
 
@@ -320,9 +330,10 @@ class FFUnit(Hinawa.SndUnit):
         offset = FFOutRegs.calculate_out_offset(self.__spec, target)
         val = self.__build_val_from_db(db)
         data = pack('<I', val)
-        req = Hinawa.FwReq()
-        req.transaction(self.get_node(), Hinawa.FwTcode.WRITE_BLOCK_REQUEST,
-                        self.__regs[2] + offset, len(data), data)
+        req = Hinawa.FwReq.new()
+        _, _ = req.transaction(self.get_node(),
+                               Hinawa.FwTcode.WRITE_BLOCK_REQUEST,
+                               self.__regs[2] + offset, len(data), data, 100)
         self.__out_cache[offset // 4] = val
 
     def get_out_volume(self, target):
