@@ -8,8 +8,8 @@ from signal import SIGINT
 
 import gi
 gi.require_version('GLib', '2.0')
-gi.require_version('Hinawa', '3.0')
-from gi.repository import GLib, Hinawa
+gi.require_version('Hitaki', '0.0')
+from gi.repository import GLib, Hitaki
 
 __all__ = ['CliKit']
 
@@ -20,8 +20,8 @@ class CliKit():
         for fullpath in Path('/dev/snd').glob('hw*'):
             fullpath = str(fullpath)
             try:
-                unit = Hinawa.SndUnit()
-                unit.open(fullpath)
+                unit = Hitaki.SndUnit()
+                unit.open(fullpath, 0)
                 if unit.get_property('guid') == guid:
                     return fullpath
             except Exception as e:
@@ -43,19 +43,30 @@ class CliKit():
             return True
 
     @staticmethod
-    def _dump_help(cmdline):
+    def _dump_deprecation_text():
+        print('  NOTICE')
+        print('    This tool has been already abandoned. Please look into the migration')
+        print('    to successive project:')
+        print('      https://github.com/alsa-project/snd-firewire-ctl-services')
+
+    @classmethod
+    def _dump_help(cls, cmdline):
         print('{0} CARD|GUID [FILE|CMD [ARGS]]'.format(cmdline))
         print('  CARD:  the number as ALSA sound card, see /proc/asound/cards.')
         print('  GUID:  global unique ID for your unit.')
         print('  FILE:  path for a file with command list')
         print('  CMD:   issue which you need')
         print('  ARGS:  arguments for the command')
+        print('')
+        cls._dump_deprecation_text()
 
-    @staticmethod
-    def _dump_commands(cmds):
+    @classmethod
+    def _dump_commands(cls, cmds):
         print('Available commands:')
         for name in cmds.keys():
             print('  {0}'.format(name))
+        print('')
+        cls._dump_deprecation_text()
 
     @classmethod
     def seek_snd_unit_path(cls):
